@@ -3,7 +3,6 @@ from kivy.uix.widget import Widget
 from kivy.properties import NumericProperty, ReferenceListProperty,\
     ObjectProperty
 from kivy.vector import Vector
-from kivy.factory import Factory
 from kivy.clock import Clock
 from random import randint
 
@@ -44,6 +43,5 @@ class PongApp(App):
         return game
 
 
-Factory.register("PongBall", PongBall)
 if __name__ == '__main__':
     PongApp().run()
