@@ -32,12 +32,14 @@ def core_select_lib(category, llist, create_instance=False):
     if 'KIVY_DOC' in os.environ:
         return
     category = category.lower()
+    libs_ignored = []
     for option, modulename, classname in llist:
         try:
             # module activated in config ?
             if option not in kivy.kivy_options[category]:
-                Logger.debug('%s: option <%s> ignored by config' %
-                    (category.capitalize(), option))
+                libs_ignored.append(modulename)
+                Logger.debug('{0}: Provider <{1}> ignored by config'.format(
+                    category.capitalize(), option))
                 continue
 
             # import module
@@ -48,45 +50,51 @@ def core_select_lib(category, llist, create_instance=False):
             cls = mod.__getattribute__(classname)
 
             # ok !
-            Logger.info('%s: using <%s> as %s provider' %
-                (category.capitalize(), option, category))
+            Logger.info('{0}: Provider: {1}{2}'.format(
+                category.capitalize(), option,
+                '({0} ignored)'.format(libs_ignored) if libs_ignored else ''))
             if create_instance:
                 cls = cls()
             return cls
 
         except ImportError as e:
-            Logger.warning('%s: Unable to use <%s> as %s'
-                    'provider' % (category.capitalize(), option, category))
-            Logger.warning('%s: Associated module are missing' %
-                    (category.capitalize()))
-            Logger.debug('', exc_info=e)
+            libs_ignored.append(modulename)
+            Logger.debug('{0}: Ignored <{1}> (import error)'.format(
+                category.capitalize(), option))
+            Logger.trace('', exc_info=e)
 
         except CoreCriticalException as e:
-            Logger.error('%s: Unable to use <%s> as %s'
-                    'provider' % (category.capitalize(), option, category))
-            Logger.error('%s: The module raised an important error: %r' %
-                    (category.capitalize(), e.message))
+            Logger.error('{0}: Unable to use {1}'.format(
+                    category.capitalize(), option))
+            Logger.error(
+                    '{0}: The module raised an important error: {1!r}'.format(
+                    category.capitalize(), e.message))
             raise
 
         except Exception as e:
-            Logger.warning('%s: Unable to use <%s> as %s'
-                    'provider' % (category.capitalize(), option, category))
-            Logger.debug('', exc_info=e)
+            libs_ignored.append(modulename)
+            Logger.trace('{0}: Unable to use {1}'.format(
+                category.capitalize(), option, category))
+            Logger.trace('', exc_info=e)
 
-    Logger.critical('%s: Unable to find any valuable %s provider '
-            'at all!' % (category.capitalize(), category.capitalize()))
+    Logger.critical(
+        '{0}: Unable to find any valuable {1} provider at all!'.format(
+        category.capitalize(), category.capitalize()))
 
 
 def core_register_libs(category, libs):
     if 'KIVY_DOC' in os.environ:
         return
     category = category.lower()
+    libs_loaded = []
+    libs_ignored = []
     for option, lib in libs:
         try:
             # module activated in config ?
             if option not in kivy.kivy_options[category]:
-                Logger.debug('%s: option <%s> ignored by config' %
-                    (category.capitalize(), option))
+                Logger.debug('{0}: option <{1}> ignored by config'.format(
+                    category.capitalize(), option))
+                libs_ignored.append(lib)
                 continue
 
             # import module
@@ -96,8 +104,16 @@ def core_register_libs(category, libs):
                         fromlist=[lib],
                         level=-1)
 
+            libs_loaded.append(lib)
+
         except Exception as e:
-            Logger.warning('%s: Unable to use <%s> as loader!' %
-                (category.capitalize(), option))
-            Logger.debug('', exc_info=e)
+            Logger.trace('{0}: Unable to use <{1}> as loader!'.format(
+                category.capitalize(), option))
+            Logger.trace('', exc_info=e)
+            libs_ignored.append(lib)
+
+    Logger.info('{0}: Providers: {1} {2}'.format(
+        category.capitalize(),
+        ', '.join(libs_loaded),
+        '({0} ignored)'.format(', '.join(libs_ignored)) if libs_ignored else ''))
 
