@@ -44,7 +44,8 @@ class ImageData(object):
 
     __slots__ = ('fmt', 'mipmaps', 'source', 'flip_vertical')
     _supported_fmts = ('rgb', 'rgba', 'bgr', 'bgra',
-            's3tc_dxt1', 's3tc_dxt3', 's3tc_dxt5')
+            's3tc_dxt1', 's3tc_dxt3', 's3tc_dxt5',
+            'pvrtc_rgb2', 'pvrtc_rgb4', 'pvrtc_rgba2', 'pvrtc_rgba4')
 
     def __init__(self, width, height, fmt, data, source=None, flip_vertical=True):
         assert fmt in ImageData._supported_fmts
@@ -222,6 +223,14 @@ class ImageLoaderBase(object):
             self.populate()
         return self._textures
 
+    @property
+    def nocache(self):
+        '''Indicate if the texture will not be stored in the cache
+
+        .. versionadded:: 1.6.0
+        '''
+        return self._nocache
+
 
 class ImageLoader(object):
     __slots__ = ('loaders')
@@ -242,6 +251,7 @@ class ImageLoader(object):
         # sort filename list
         znamelist = z.namelist()
         znamelist.sort()
+        image = None
         for zfilename in znamelist:
             try:
                 #read file and store it in mem with fileIO struct around it
@@ -253,11 +263,16 @@ class ImageLoader(object):
                         continue
                     Logger.debug('Image%s: Load <%s> from <%s>' %
                             (loader.__name__[11:], zfilename, filename))
-                    im = loader(tmpfile, **kwargs)
+                    try:
+                        im = loader(tmpfile, **kwargs)
+                    except:
+                        # Loader failed, continue trying.
+                        continue
                     break
                 if im is not None:
                     # append ImageData to local variable before it's overwritten
                     image_data.append(im._data[0])
+                    image = im 
                 #else: if not image file skip to next
             except:
                 Logger.warning('Image: Unable to load image' +
@@ -267,9 +282,9 @@ class ImageLoader(object):
         if len(image_data) == 0:
             raise Exception('no images in zip <%s>' % filename)
         # replace Image.Data with the array of all the images in the zip
-        im._data = image_data
-        im.filename = filename
-        return im
+        image._data = image_data
+        image.filename = filename
+        return image
 
     @staticmethod
     def register(defcls):
@@ -295,7 +310,6 @@ class ImageLoader(object):
             # because when it's not in use, the texture can be removed from the
             # kv.texture cache.
             if atlas:
-                #print 'ATLAS REUSE', filename
                 texture = atlas[uid]
                 fn = 'atlas://%s/%s' % (rfn, uid)
                 cid = '%s|%s|%s' % (fn, False, 0)
@@ -309,14 +323,12 @@ class ImageLoader(object):
             afn = resource_find(afn)
             if not afn:
                 raise Exception('Unable to found %r atlas' % afn)
-            #print 'ATLAS LOAD', filename
             atlas = Atlas(afn)
             Cache.append('kv.atlas', rfn, atlas)
             # first time, fill our texture cache.
             for nid, texture in atlas.textures.iteritems():
                 fn = 'atlas://%s/%s' % (rfn, nid)
                 cid = '%s|%s|%s' % (fn, False, 0)
-                #print 'register', cid
                 Cache.append('kv.texture', cid, texture)
             return Image(atlas[uid])
 
@@ -350,12 +362,12 @@ class Image(EventDispatcher):
     '''Load an image, and store the size and texture.
 
     .. versionadded::
-        In 1.0.7, mipmap attribute have been added, texture_mipmap and
+        In 1.0.7, mipmap attribute has been added, texture_mipmap and
         texture_rectangle have been deleted.
 
     .. versionadded::
-        In 1.0.8, Image widget might change itself the texture. A new event
-        'on_texture' have been introduced. New methods for handling sequenced
+        In 1.0.8, an Image widget might change its texture. A new event
+        'on_texture' has been introduced. New methods for handling sequenced
         animation too.
 
     :Parameters:
@@ -607,7 +619,8 @@ class Image(EventDispatcher):
             self._size = image.size
         else:
             self.image = image
-            Cache.append('kv.image', uid, self.image)
+            if not self._nocache:
+                Cache.append('kv.image', uid, self.image)
 
     filename = property(_get_filename, _set_filename,
             doc='Get/set the filename of image')
@@ -638,6 +651,14 @@ class Image(EventDispatcher):
                 self._img_iterate()
         return self._texture
 
+    @property
+    def nocache(self):
+        '''Indicate if the texture will not be stored in the cache
+
+        .. versionadded:: 1.6.0
+        '''
+        return self._nocache
+
     def read_pixel(self, x, y):
         '''For a given local x/y position, return the color at that position.
 
@@ -689,6 +710,7 @@ image_libs = []
 if platform() in ('macosx', 'ios'):
     image_libs += [('imageio', 'img_imageio')]
 image_libs += [
+    ('tex', 'img_tex'),
     ('dds', 'img_dds'),
     ('pygame', 'img_pygame'),
     ('pil', 'img_pil'),
