@@ -270,7 +270,7 @@ class WindowBase(EventDispatcher):
             return True
         else:
             return False
-    size = AliasProperty(_get_size, _set_size)
+    size = AliasProperty(_get_size, _set_size, bind=('_size', ))
     '''Get the rotated size of the window. If :data:`rotation` is set, then the
     size will change to reflect the rotation.
     '''
@@ -476,8 +476,8 @@ class WindowBase(EventDispatcher):
         self.create_window()
 
         # attach modules + listener event
-        Modules.register_window(self)
         EventLoop.set_window(self)
+        Modules.register_window(self)
         EventLoop.add_event_listener(self)
 
         # manage keyboard(s)
@@ -539,6 +539,7 @@ class WindowBase(EventDispatcher):
                 from kivy.graphics.context import get_context
                 get_context().reload()
                 Clock.schedule_once(lambda x: self.canvas.ask_update(), 0)
+                self.dispatch('on_resize', *self.system_size)
 
         # ensure the gl viewport is correct
         self.update_viewport()
@@ -984,4 +985,6 @@ class WindowBase(EventDispatcher):
 #: Instance of a :class:`WindowBase` implementation
 Window = core_select_lib('window', (
     ('pygame', 'window_pygame', 'WindowPygame'),
+    ('sdl', 'window_sdl', 'WindowSDL'),
+    ('x11', 'window_x11', 'WindowX11'),
 ), True)
