@@ -117,8 +117,12 @@ class ModuleBase:
             module = __import__(name=modname)
             module = sys.modules[modname]
         except ImportError:
-            Logger.exception('Modules: unable to import <%s>' % name)
-            raise
+            try:
+                module = __import__(name=name)
+                module = sys.modules[name]
+            except ImportError:
+                Logger.exception('Modules: unable to import <%s>' % name)
+                raise
         # basic check on module
         if not hasattr(module, 'start'):
             Logger.warning('Modules: Module <%s> missing start() function' %
@@ -175,7 +179,12 @@ class ModuleBase:
                 if not name in modules_to_activate:
                     self.deactivate_module(name, win)
             for name in modules_to_activate:
-                self.activate_module(name, win)
+                try:
+                    self.activate_module(name, win)
+                except:
+                    import traceback
+                    traceback.print_exc()
+                    raise
 
     def configure(self):
         '''(internal) Configure all the modules before using it.
