@@ -12,8 +12,9 @@ will cover the whole "parent" window. When you are creating a popup, you must at
 a minimum set a :data:`Popup.title` and a :data:`Popup.content` widget.
 
 Remember that the default size of a Widget is size_hint=(1, 1). If you don't
-want your popup to be fullscreen, deactivate the size_hint and use a specific
-size attribute.
+want your popup to be fullscreen, either use lower than 1 size hints (for
+instance size_hint=(.8, .8)) or deactivate the size_hint and use fixed size
+attributes.
 
 
 .. versionchanged:: 1.4.0
@@ -115,17 +116,17 @@ class Popup(ModalView):
 
     .. versionadded:: 1.1.0
 
-    :data:`background_color` is a :class:`~kivy.properties.ListProperty`,
+    :data:`separator_color` is a :class:`~kivy.properties.ListProperty`,
     default to [47 / 255., 167 / 255., 212 / 255., 1.]
     '''
 
-    separator_height = NumericProperty(2)
+    separator_height = NumericProperty('2dp')
     '''Height of the separator.
 
     .. versionadded:: 1.1.0
 
     :data:`separator_height` is a :class:`~kivy.properties.NumericProperty`,
-    default to 2.
+    default to 2dp.
     '''
 
     # Internals properties used for graphical representation.
