@@ -139,12 +139,31 @@ from kivy.graphics import RenderContext, Rectangle, Fbo, \
 
 
 class ScreenManagerException(Exception):
+    '''Exception of the :class:`ScreenManager`
+    '''
     pass
 
 
 class Screen(RelativeLayout):
     '''Screen is an element intented to be used within :class:`ScreenManager`.
     Check module documentation for more information.
+
+    :Events:
+        `on_pre_enter`: ()
+            Event fired when the screen is about to be used: the entering
+            animation is started.
+        `on_enter`: ()
+            Event fired when the screen is displayed: the entering animation is
+            complete.
+        `on_pre_leave`: ()
+            Event fired when the screen is about to be removed: the leaving
+            animation is started.
+        `on_leave`: ()
+            Event fired when the screen is removed: the leaving animation is
+            finished.
+
+    .. versionchanged:: 1.6.0
+        Events `on_pre_enter`, `on_enter`, `on_pre_leave`, `on_leave` is added.
     '''
 
     name = StringProperty('')
@@ -187,6 +206,25 @@ class Screen(RelativeLayout):
     default to 'out'.
     '''
 
+    def __init__(self, **kwargs):
+        self.register_event_type('on_pre_enter')
+        self.register_event_type('on_enter')
+        self.register_event_type('on_pre_leave')
+        self.register_event_type('on_leave')
+        super(Screen, self).__init__(**kwargs)
+
+    def on_pre_enter(self, *args):
+        pass
+
+    def on_enter(self, *args):
+        pass
+
+    def on_pre_leave(self, *args):
+        pass
+
+    def on_leave(self, *args):
+        pass
+
     def __repr__(self):
         return '<Screen name=%r>' % self.name
 
@@ -265,6 +303,8 @@ class TransitionBase(EventDispatcher):
         self.screen_in.transition_state = 'in'
         self.screen_out.transition_progress = 0.
         self.screen_out.transition_state = 'out'
+        self.screen_in.dispatch('on_pre_enter')
+        self.screen_out.dispatch('on_pre_leave')
 
         self.is_active = True
         self._anim.start(self)
@@ -305,6 +345,8 @@ class TransitionBase(EventDispatcher):
     def _on_complete(self, *l):
         self.is_active = False
         self.dispatch('on_complete')
+        self.screen_in.dispatch('on_enter')
+        self.screen_out.dispatch('on_leave')
         self._anim = None
 
 
@@ -350,7 +392,7 @@ class ShaderTransition(TransitionBase):
     def make_screen_fbo(self, screen):
         fbo = Fbo(size=screen.size)
         with fbo:
-            ClearColor(0, 1, 0, 1)
+            ClearColor(0, 0, 0, 1)
             ClearBuffers()
         fbo.add(screen.canvas)
         return fbo
@@ -650,10 +692,12 @@ class ScreenManager(FloatLayout):
         else:
             screen.pos = self.pos
             self.real_add_widget(screen)
+            screen.dispatch('on_pre_enter')
+            screen.dispatch('on_enter')
 
     def get_screen(self, name):
-        '''Return the screen widget associated to the name, or None if not
-        found.
+        '''Return the screen widget associated to the name, or raise a
+        :class:`ScreenManagerException` if not found.
         '''
         matches = [s for s in self.screens if s.name == name]
         num_matches = len(matches)
@@ -663,6 +707,13 @@ class ScreenManager(FloatLayout):
             Logger.warn('Multiple screens named "%s": %s' % (name, matches))
         return matches[0]
 
+    def has_screen(self, name):
+        '''Return True if a screen with the `name` has been found.
+
+        .. versionadded:: 1.6.0
+        '''
+        return bool([s for s in self.screens if s.name == name])
+
     def next(self):
         '''Return the name of the next screen from the screen list.
         '''
