@@ -82,6 +82,15 @@ class Video(Image):
     False.
     '''
 
+    loaded = BooleanProperty(False)
+    '''Boolean, indicates if the video is loaded and ready for playback.
+
+    .. versionadded:: 1.6.0
+
+    :data:`loaded` is a :class:`~kivy.properties.BooleanProperty`, default to
+    False.
+    '''
+
     position = NumericProperty(-1)
     '''Position of the video between 0 and :data:`duration`. The position
     defaults to -1, and is set to a real position when the video is loaded.
@@ -153,7 +162,7 @@ class Video(Image):
                 filename = resource_find(filename)
             self._video = CoreVideo(filename=filename, **self.options)
             self._video.volume = self.volume
-            self._video.bind(on_load=self._on_video_frame,
+            self._video.bind(on_load=self._on_load,
                              on_frame=self._on_video_frame,
                              on_eos=self._on_eos)
             if self.state == 'play' or self.play:
@@ -192,6 +201,10 @@ class Video(Image):
         self.state = 'stop'
         self.eos = True
 
+    def _on_load(self, *largs):
+        self.loaded = True
+        self._on_video_frame(largs)
+
     def on_volume(self, instance, value):
         if self._video:
             self._video.volume = value
