@@ -47,8 +47,8 @@ We also have some defaults that you should be aware of:
 * The default size_hint is (1, 1). If the parent is a :class:`Layout`, then the
   widget size will be the parent/layout size.
 
-* All the :meth:`Widget.on_touch_down`, :meth:`Widget.on_touch_move`,
-  :meth:`Widget.on_touch_up` doesn't do any sort of collisions. If you want to
+* :meth:`Widget.on_touch_down`, :meth:`Widget.on_touch_move`,
+  :meth:`Widget.on_touch_up` don't do any sort of collisions. If you want to
   know if the touch is inside your widget, use :meth:`Widget.collide_point`.
 
 Using Properties
